@@ -33,7 +33,6 @@ class SourceDevice:
         self.log_parent_path = log_path.parent
         self.log_filename = log_path.name
         self.log_modified_time = getmtime(log_path)
-        self.device_type = None
         self.device_name = None
         self.ip, self.netmask, self.gateway = self.parse_net_info()
         self.site_name = None
@@ -147,7 +146,7 @@ class SourceDevice:
                         error_codes[2] + '\nCurrent: {}'.format(self.netmask))
         if self.gateway.rsplit('.', 1)[1] != ip_info['gw']:
             error.append(f'{self.hostname} ' +
-                        error_codes[3] + '\nCurrent: {}'.format(net_info['gateway']))
+                        error_codes[3] + '\nCurrent: {}'.format(self.gateway))
 
         return error
 
